@@ -23,7 +23,7 @@ class AccessTokenExpired(Exception):
     """Raised when access token has already expired."""
 
 
-def decode_jwt_payload(access_token: str) -> Dict[str, Any]:
+def _decode_jwt_payload(access_token: str) -> Dict[str, Any]:
     """Extract the JWT payload without performing signature validation."""
     try:
         parts = access_token.split(".")
@@ -40,9 +40,9 @@ def decode_jwt_payload(access_token: str) -> Dict[str, Any]:
         raise AccessTokenInvalid
 
 
-def validate_access_token(access_token: str) -> str:
+def _validate_access_token(access_token: str) -> str:
     """Return the access token if valid or raise a related exception."""
-    payload = decode_jwt_payload(access_token)
+    payload = _decode_jwt_payload(access_token)
 
     expires_at = payload.get("exp", 0)
     if expires_at < time.time():
@@ -65,7 +65,7 @@ class BaseClient(ABC):
             concurrency_limit: maximum allowed concurrent API requests
             base_url: root url for API resources
         """
-        self.access_token = validate_access_token(access_token)
+        self.access_token = _validate_access_token(access_token)
         self.concurrency_limit = concurrency_limit
         self.base_url = base_url
 
