@@ -57,6 +57,7 @@ class BaseBalancesResource:
         utc_starttime: Optional[datetime] = None,
         utc_endtime: Optional[datetime] = None,
         labels: Optional[Sequence[str]] = None,
+        account_types: Optional[Sequence[AccountType]] = None,
         page: int = 1,
     ) -> BalancesResponse:
         async with self._client.session() as session:
@@ -66,6 +67,7 @@ class BaseBalancesResource:
                     utc_starttime=utc_starttime,
                     utc_endtime=utc_endtime,
                     labels=labels,
+                    account_types=account_types,
                     page=page,
                 ),
             )
@@ -81,6 +83,7 @@ class BaseBalancesResource:
         utc_starttime: Optional[datetime] = None,
         utc_endtime: Optional[datetime] = None,
         labels: Optional[Sequence[str]] = None,
+        account_types: Optional[Sequence[AccountType]] = None,
     ) -> List[BalanceRecord]:
         response = await self._get_page(
             user_uuid=user_uuid,
@@ -88,6 +91,7 @@ class BaseBalancesResource:
             utc_starttime=utc_starttime,
             utc_endtime=utc_endtime,
             labels=labels,
+            account_types=account_types,
         )
         max_pages = response.meta.max_pages
         if max_pages > 1:
@@ -98,6 +102,7 @@ class BaseBalancesResource:
                     utc_starttime=utc_starttime,
                     utc_endtime=utc_endtime,
                     labels=labels,
+                    account_types=account_types,
                     page=page + 2,
                 )
                 for page in range(max_pages - 1)
@@ -124,6 +129,7 @@ class AsyncBalancesResource(BaseBalancesResource):
         utc_starttime: Optional[datetime] = None,
         utc_endtime: Optional[datetime] = None,
         labels: Optional[Sequence[str]] = None,
+        account_types: Optional[Sequence[AccountType]] = None,
     ) -> List[BalanceRecord]:
         return await self._get(
             user_uuid=user_uuid,
@@ -131,6 +137,7 @@ class AsyncBalancesResource(BaseBalancesResource):
             utc_starttime=utc_starttime,
             utc_endtime=utc_endtime,
             labels=labels,
+            account_types=account_types,
         )
 
 
@@ -143,6 +150,7 @@ class SyncBalancesResource(BaseBalancesResource):
         utc_starttime: Optional[datetime] = None,
         utc_endtime: Optional[datetime] = None,
         labels: Optional[Sequence[str]] = None,
+        account_types: Optional[Sequence[AccountType]] = None,
     ) -> List[BalanceRecord]:
         return self._client.run(
             self._get(
@@ -151,5 +159,6 @@ class SyncBalancesResource(BaseBalancesResource):
                 utc_starttime=utc_starttime,
                 utc_endtime=utc_endtime,
                 labels=labels,
+                account_types=account_types,
             )
         )
