@@ -1,6 +1,6 @@
 from typing import List
 
-from pydantic import BaseModel
+from pydantic import BaseModel, validate_arguments
 
 from ..core import BaseClient
 from ..types import AccountType, Currency
@@ -8,14 +8,9 @@ from ..types import AccountType, Currency
 PATH = "/users/{user_uuid}/institutions"
 
 
-class InstitutionNames(BaseModel):
-    name: str
-    display_name: str
-
-
 class Institution(BaseModel):
     institution_id: str
-    institution: InstitutionNames
+    display_name: str
     currency: Currency
     account_types: List[AccountType]
 
@@ -37,6 +32,7 @@ class BaseInstitutionsResource:
     def __init__(self, client: BaseClient):
         self._client = client
 
+    @validate_arguments
     async def _get(self, user_uuid: str) -> List[Institution]:
         async with self._client.session() as session:
             response = await session.get(PATH.format(user_uuid=user_uuid))
