@@ -58,6 +58,7 @@ class BaseTransactionsResource:
         utc_starttime: Optional[datetime] = None,
         utc_endtime: Optional[datetime] = None,
         labels: Optional[Sequence[str]] = None,
+        account_types: Optional[Sequence[AccountType]] = None,
         page: int = 1,
     ) -> TransactionsResponse:
         async with self._client.session() as session:
@@ -67,6 +68,7 @@ class BaseTransactionsResource:
                     utc_starttime=utc_starttime,
                     utc_endtime=utc_endtime,
                     labels=labels,
+                    account_types=account_types,
                     page=page,
                 ),
             )
@@ -82,6 +84,7 @@ class BaseTransactionsResource:
         utc_starttime: Optional[datetime] = None,
         utc_endtime: Optional[datetime] = None,
         labels: Optional[Sequence[str]] = None,
+        account_types: Optional[Sequence[AccountType]] = None,
     ) -> List[TransactionRecord]:
         response = await self._get_page(
             user_uuid=user_uuid,
@@ -89,6 +92,7 @@ class BaseTransactionsResource:
             utc_starttime=utc_starttime,
             utc_endtime=utc_endtime,
             labels=labels,
+            account_types=account_types,
         )
         max_pages = response.meta.max_pages
         if max_pages > 1:
@@ -99,6 +103,7 @@ class BaseTransactionsResource:
                     utc_starttime=utc_starttime,
                     utc_endtime=utc_endtime,
                     labels=labels,
+                    account_types=account_types,
                     page=page + 2,
                 )
                 for page in range(max_pages - 1)
@@ -125,6 +130,7 @@ class AsyncTransactionsResource(BaseTransactionsResource):
         utc_starttime: Optional[datetime] = None,
         utc_endtime: Optional[datetime] = None,
         labels: Optional[Sequence[str]] = None,
+        account_types: Optional[Sequence[AccountType]] = None,
     ) -> List[TransactionRecord]:
         return await self._get(
             user_uuid=user_uuid,
@@ -132,6 +138,7 @@ class AsyncTransactionsResource(BaseTransactionsResource):
             utc_starttime=utc_starttime,
             utc_endtime=utc_endtime,
             labels=labels,
+            account_types=account_types,
         )
 
 
@@ -144,6 +151,7 @@ class SyncTransactionsResource(BaseTransactionsResource):
         utc_starttime: Optional[datetime] = None,
         utc_endtime: Optional[datetime] = None,
         labels: Optional[Sequence[str]] = None,
+        account_types: Optional[Sequence[AccountType]] = None,
     ) -> List[TransactionRecord]:
         return self._client.run(
             self._get(
@@ -152,5 +160,6 @@ class SyncTransactionsResource(BaseTransactionsResource):
                 utc_starttime=utc_starttime,
                 utc_endtime=utc_endtime,
                 labels=labels,
+                account_types=account_types,
             )
         )
