@@ -49,11 +49,19 @@ class BaseUsersResource(ABC):
     def __init__(self, client: BaseClient):
         self._client = client
 
-    async def _get_page(self, search: Optional[str], page: int = 1) -> UsersResponse:
+    async def _get_page(
+        self,
+        created_after: Optional[datetime] = None,
+        created_before: Optional[datetime] = None,
+        search: Optional[str] = None,
+        page: int = 1,
+    ) -> UsersResponse:
         async with self._client.session() as session:
             response = await session.get(
                 PATH,
                 params=encode_query_params(
+                    created_after=created_after,
+                    created_before=created_before,
                     search=search,
                     page=page,
                 ),
@@ -63,12 +71,27 @@ class BaseUsersResource(ABC):
         return UsersResponse(**response.json())
 
     @validate_arguments
-    async def _get(self, search: Optional[str] = None) -> List[User]:
-        response = await self._get_page(search)
+    async def _get(
+        self,
+        created_after: Optional[datetime] = None,
+        created_before: Optional[datetime] = None,
+        search: Optional[str] = None,
+    ) -> List[User]:
+        response = await self._get_page(
+            created_after=created_after,
+            created_before=created_before,
+            search=search,
+        )
         max_pages = response.meta.max_pages
         if max_pages > 1:
             coroutines = [
-                self._get_page(search, page + 2) for page in range(max_pages - 1)
+                self._get_page(
+                    created_after=created_after,
+                    created_before=created_before,
+                    search=search,
+                    page=page + 2,
+                )
+                for page in range(max_pages - 1)
             ]
             response_pages = await asyncio.gather(*coroutines)
             responses = (response, *response_pages)
@@ -79,10 +102,32 @@ class BaseUsersResource(ABC):
 
 
 class AsyncUsersResource(BaseUsersResource):
-    async def get(self, search: Optional[str] = None) -> List[User]:
-        return await self._get(search)
+    async def get(
+        self,
+        *,
+        created_after: Optional[datetime] = None,
+        created_before: Optional[datetime] = None,
+        search: Optional[str] = None,
+    ) -> List[User]:
+        return await self._get(
+            created_after=created_after,
+            created_before=created_before,
+            search=search,
+        )
 
 
 class SyncUsersResource(BaseUsersResource):
-    def get(self, search: Optional[str] = None) -> List[User]:
-        return self._client.run(self._get(search))
+    def get(
+        self,
+        *,
+        created_after: Optional[datetime] = None,
+        created_before: Optional[datetime] = None,
+        search: Optional[str] = None,
+    ) -> List[User]:
+        return self._client.run(
+            self._get(
+                created_after=created_after,
+                created_before=created_before,
+                search=search,
+            )
+        )
